==> rectanglepy-0.0.45.tar.gz: rectanglepy-0.0.45/README.md <==
# Rectangle

[![Tests][badge-tests]][link-tests]
[![Documentation][badge-docs]][link-docs]

[badge-tests]: https://img.shields.io/github/actions/workflow/status/bernheder/Rectangle/test.yaml?branch=main
[link-tests]: https://github.com/ComputationalBiomedicineGroup/Rectangle/actions/workflows/build.yaml
[badge-docs]: https://img.shields.io/readthedocs/Rectangle

Rectangle embodies a ”second-generation” deconvolution methodology, setting itself apart from other second-generation
methods through its efficiency in signature creation and its handling of challenges within the deconvolution process.
To establish a precise deconvolution method, we employ a hierarchical analysis approach, incorporate mRNA bias
correction, and provide an estimation of unknown cellular content.

## Getting started

Please refer to the [documentation][link-docs]. In particular, the

-   [API documentation][link-api].

## Installation

You need to have Python 3.10 or newer installed on your system. If you don't have
Python installed, we recommend installing [Mambaforge](https://github.com/conda-forge/miniforge#mambaforge).

How to install Rectangle:

Install the latest release of `Rectangle` from `PyPI <https://pypi.org/project/rectanglepy/>`:

```bash
pip install rectanglepy
```

## Release notes

See the [changelog][changelog].

## Contact

If you found a bug, please use the [issue tracker][issue-tracker].

## Citation

> t.b.a

[scverse-discourse]: https://discourse.scverse.org/
[issue-tracker]: https://github.com/ComputationalBiomedicineGroup/Rectangle/issues
[changelog]: https://Rectanglepy.readthedocs.io/latest/changelog.html
[link-docs]: https://Rectanglepy.readthedocs.io
[link-api]: https://rectanglepy.readthedocs.io/api.html

==> rectanglepy-0.1.3.tar.gz: rectanglepy-0.1.3/README.md <==
# Rectangle

[![Tests][badge-tests]][link-tests]
[![Documentation][badge-docs]][link-docs]

[badge-tests]: https://img.shields.io/github/actions/workflow/status/ComputationalBiomedicineGroup/Rectangle/build.yaml?branch=main
[link-tests]: https://github.com/ComputationalBiomedicineGroup/Rectangle/actions/workflows/build.yaml
[badge-docs]: https://img.shields.io/readthedocs/rectanglepy

Rectangle embodies a ”second-generation” deconvolution methodology, setting itself apart from other second-generation
methods through its efficiency in signature creation and its handling of challenges within the deconvolution process.
To establish a precise deconvolution method, we employ a hierarchical analysis approach, incorporate mRNA bias
correction, and provide an estimation of unknown cellular content.

## Getting started

Please refer to the [documentation][link-docs]. In particular, the

-   [API documentation][link-api].

## Installation

You need to have Python 3.10 or newer installed on your system. If you don't have
Python installed, we recommend installing [Mambaforge](https://github.com/conda-forge/miniforge#mambaforge).

How to install Rectangle:

Install the latest release of `Rectangle` from `PyPI <https://pypi.org/project/rectanglepy/>`:

```bash
pip install rectanglepy
```

## Release notes

See the [changelog][changelog].

## Contact

If you found a bug, please use the [issue tracker][issue-tracker].

## Citation

> t.b.a

[scverse-discourse]: https://discourse.scverse.org/
[issue-tracker]: https://github.com/ComputationalBiomedicineGroup/Rectangle/issues
[changelog]: https://rectanglepy.readthedocs.io/changelog.html
[link-docs]: https://Rectanglepy.readthedocs.io
[link-api]: https://rectanglepy.readthedocs.io/api.html
